@@ -50,7 +50,14 @@ class InstanceEndpointAclPolicy(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(InstanceEndpointAclPolicy.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["InstanceEndpointAclPolicyProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -103,7 +110,17 @@ class InstanceEndpointAclPolicyProps:
         :param region_id: Property regionId: Region ID of instance. Default is current region.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(InstanceEndpointAclPolicyProps.__init__)
+            def stub(
+                *,
+                entry: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                instance_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                comment: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                endpoint_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                module_name: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                region_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument entry", value=entry, expected_type=type_hints["entry"])
             check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
             check_type(argname="argument comment", value=comment, expected_type=type_hints["comment"])
@@ -214,7 +231,14 @@ class Namespace(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Namespace.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["NamespaceProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -267,7 +291,15 @@ class NamespaceProps:
         :param instance_id: Property instanceId: The ID of the enterprise edition instance which namespace belongs to. If not provided, will use personal edition instance as default.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NamespaceProps.__init__)
+            def stub(
+                *,
+                namespace: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                auto_create: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                default_visibility: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                instance_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
             check_type(argname="argument auto_create", value=auto_create, expected_type=type_hints["auto_create"])
             check_type(argname="argument default_visibility", value=default_visibility, expected_type=type_hints["default_visibility"])
@@ -357,7 +389,14 @@ class Repository(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Repository.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RepositoryProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -434,7 +473,19 @@ class RepositoryProps:
         :param tag_immutability: Property tagImmutability: Specifies whether the repository is immutable. Only takes effect when InstanceId is specified.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RepositoryProps.__init__)
+            def stub(
+                *,
+                repo_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                repo_namespace: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                repo_type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                summary: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                detail: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                instance_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                repo_source: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosRepository.RepoSourceProperty", typing.Dict[str, typing.Any]]]] = None,
+                tag_immutability: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument repo_name", value=repo_name, expected_type=type_hints["repo_name"])
             check_type(argname="argument repo_namespace", value=repo_namespace, expected_type=type_hints["repo_namespace"])
             check_type(argname="argument repo_type", value=repo_type, expected_type=type_hints["repo_type"])
@@ -561,7 +612,14 @@ class RosInstanceEndpointAclPolicy(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosInstanceEndpointAclPolicy.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosInstanceEndpointAclPolicyProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -577,7 +635,9 @@ class RosInstanceEndpointAclPolicy(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosInstanceEndpointAclPolicy._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -616,7 +676,9 @@ class RosInstanceEndpointAclPolicy(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstanceEndpointAclPolicy, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -634,7 +696,11 @@ class RosInstanceEndpointAclPolicy(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstanceEndpointAclPolicy, "entry").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "entry", value)
 
@@ -652,7 +718,11 @@ class RosInstanceEndpointAclPolicy(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstanceEndpointAclPolicy, "instance_id").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceId", value)
 
@@ -672,7 +742,11 @@ class RosInstanceEndpointAclPolicy(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstanceEndpointAclPolicy, "comment").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "comment", value)
 
@@ -692,7 +766,11 @@ class RosInstanceEndpointAclPolicy(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstanceEndpointAclPolicy, "endpoint_type").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "endpointType", value)
 
@@ -715,7 +793,11 @@ class RosInstanceEndpointAclPolicy(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstanceEndpointAclPolicy, "module_name").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "moduleName", value)
 
@@ -735,7 +817,11 @@ class RosInstanceEndpointAclPolicy(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosInstanceEndpointAclPolicy, "region_id").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "regionId", value)
 
@@ -773,7 +859,17 @@ class RosInstanceEndpointAclPolicyProps:
         :param region_id: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosInstanceEndpointAclPolicyProps.__init__)
+            def stub(
+                *,
+                entry: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                instance_id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                comment: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                endpoint_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                module_name: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                region_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument entry", value=entry, expected_type=type_hints["entry"])
             check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
             check_type(argname="argument comment", value=comment, expected_type=type_hints["comment"])
@@ -888,7 +984,14 @@ class RosNamespace(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosNamespace.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosNamespaceProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -904,7 +1007,9 @@ class RosNamespace(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosNamespace._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -951,7 +1056,9 @@ class RosNamespace(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosNamespace, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -969,7 +1076,11 @@ class RosNamespace(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosNamespace, "namespace").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "namespace", value)
 
@@ -989,7 +1100,11 @@ class RosNamespace(
         value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosNamespace, "auto_create").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "autoCreate", value)
 
@@ -1009,7 +1124,11 @@ class RosNamespace(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosNamespace, "default_visibility").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "defaultVisibility", value)
 
@@ -1029,7 +1148,11 @@ class RosNamespace(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosNamespace, "instance_id").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceId", value)
 
@@ -1061,7 +1184,15 @@ class RosNamespaceProps:
         :param instance_id: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosNamespaceProps.__init__)
+            def stub(
+                *,
+                namespace: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                auto_create: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+                default_visibility: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                instance_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
             check_type(argname="argument auto_create", value=auto_create, expected_type=type_hints["auto_create"])
             check_type(argname="argument default_visibility", value=default_visibility, expected_type=type_hints["default_visibility"])
@@ -1149,7 +1280,14 @@ class RosRepository(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosRepository.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosRepositoryProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -1165,7 +1303,9 @@ class RosRepository(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosRepository._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -1228,7 +1368,9 @@ class RosRepository(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRepository, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -1246,7 +1388,11 @@ class RosRepository(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRepository, "repo_name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repoName", value)
 
@@ -1264,7 +1410,11 @@ class RosRepository(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRepository, "repo_namespace").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repoNamespace", value)
 
@@ -1282,7 +1432,11 @@ class RosRepository(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRepository, "repo_type").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repoType", value)
 
@@ -1300,7 +1454,11 @@ class RosRepository(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRepository, "summary").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "summary", value)
 
@@ -1320,7 +1478,11 @@ class RosRepository(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRepository, "detail").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "detail", value)
 
@@ -1340,7 +1502,11 @@ class RosRepository(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRepository, "instance_id").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceId", value)
 
@@ -1360,7 +1526,11 @@ class RosRepository(
         value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosRepository.RepoSourceProperty"]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRepository, "repo_source").fset)
+            def stub(
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosRepository.RepoSourceProperty"]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repoSource", value)
 
@@ -1380,7 +1550,11 @@ class RosRepository(
         value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRepository, "tag_immutability").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tagImmutability", value)
 
@@ -1416,7 +1590,17 @@ class RosRepository(
             :param source_repo_type: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosRepository.RepoSourceProperty.__init__)
+                def stub(
+                    *,
+                    is_auto_build: typing.Union[builtins.bool, ros_cdk_core.IResolvable],
+                    is_disable_cache: typing.Union[builtins.bool, ros_cdk_core.IResolvable],
+                    is_oversea: typing.Union[builtins.bool, ros_cdk_core.IResolvable],
+                    source_repo_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    source_repo_namespace: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    source_repo_type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument is_auto_build", value=is_auto_build, expected_type=type_hints["is_auto_build"])
                 check_type(argname="argument is_disable_cache", value=is_disable_cache, expected_type=type_hints["is_disable_cache"])
                 check_type(argname="argument is_oversea", value=is_oversea, expected_type=type_hints["is_oversea"])
@@ -1550,7 +1734,19 @@ class RosRepositoryProps:
         :param tag_immutability: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosRepositoryProps.__init__)
+            def stub(
+                *,
+                repo_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                repo_namespace: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                repo_type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                summary: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                detail: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                instance_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                repo_source: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosRepository.RepoSourceProperty, typing.Dict[str, typing.Any]]]] = None,
+                tag_immutability: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument repo_name", value=repo_name, expected_type=type_hints["repo_name"])
             check_type(argname="argument repo_namespace", value=repo_namespace, expected_type=type_hints["repo_namespace"])
             check_type(argname="argument repo_type", value=repo_type, expected_type=type_hints["repo_type"])
@@ -1684,7 +1880,14 @@ class RosUserInfo(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosUserInfo.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosUserInfoProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -1700,7 +1903,9 @@ class RosUserInfo(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosUserInfo._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -1739,7 +1944,9 @@ class RosUserInfo(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosUserInfo, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -1759,7 +1966,11 @@ class RosUserInfo(
         value: typing.Union[ros_cdk_core.IResolvable, "RosUserInfo.UserProperty"],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosUserInfo, "user").fset)
+            def stub(
+                value: typing.Union[ros_cdk_core.IResolvable, "RosUserInfo.UserProperty"],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "user", value)
 
@@ -1778,7 +1989,12 @@ class RosUserInfo(
             :param password: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosUserInfo.UserProperty.__init__)
+                def stub(
+                    *,
+                    password: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument password", value=password, expected_type=type_hints["password"])
             self._values: typing.Dict[str, typing.Any] = {
                 "password": password,
@@ -1821,7 +2037,12 @@ class RosUserInfoProps:
         :param user: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosUserInfoProps.__init__)
+            def stub(
+                *,
+                user: typing.Union[ros_cdk_core.IResolvable, typing.Union[RosUserInfo.UserProperty, typing.Dict[str, typing.Any]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument user", value=user, expected_type=type_hints["user"])
         self._values: typing.Dict[str, typing.Any] = {
             "user": user,
@@ -1874,7 +2095,14 @@ class UserInfo(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(UserInfo.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["UserInfoProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -1910,7 +2138,12 @@ class UserInfoProps:
         :param user: Property user: User info. If user exists, will update user info.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(UserInfoProps.__init__)
+            def stub(
+                *,
+                user: typing.Union[ros_cdk_core.IResolvable, typing.Union[RosUserInfo.UserProperty, typing.Dict[str, typing.Any]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument user", value=user, expected_type=type_hints["user"])
         self._values: typing.Dict[str, typing.Any] = {
             "user": user,
